@@ -81,7 +81,7 @@ class R3sponse(object):
 		if variable in ["", None]:
 			return variable, self.error_response(f"Define parameter: [{identifier}].")
 		return variable, self.success_response(f"Succesfully retrieved request parameter [{identifier}].")
-	def get_request_parameters(self, request, identifiers=[], optional=False):
+	def get_request_parameters(self, request, identifiers=[], optional=False, empty_value=None):
 		if isinstance(identifiers, str):
 			return self.error_response("__get_request_params__ is used to retrieve several identifiers (array format not string).")
 		params = {}
@@ -89,11 +89,15 @@ class R3sponse(object):
 			param_value, response = self.get_request_parameter(request, param)
 			if response["error"] != None: 
 				if optional:
-					params[param] = None
+					params[param] = empty_value
 				else:
 					return params, response
 			else: 
 				params[param] = param_value
+		if optional:
+			for key in identifiers:
+				try: params[key]
+				except: params[key] = empty_value
 		return params, self.success_response(f"Succesfully retrieved {len(params)} request parameter(s).")
 
 	# check parameters.
